@@ -1,3 +1,24 @@
+/*
+qgvdial is a cross platform Google Voice Dialer
+Copyright (C) 2010  Yuvraaj Kelkar
+
+This library is free software; you can redistribute it and/or
+modify it under the terms of the GNU Lesser General Public
+License as published by the Free Software Foundation; either
+version 2.1 of the License, or (at your option) any later version.
+
+This library is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+Lesser General Public License for more details.
+
+You should have received a copy of the GNU Lesser General Public
+License along with this library; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+
+Contact: yuvraaj@gmail.com
+*/
+
 #include "CacheDatabase.h"
 #include "GVAccess.h"
 #include "ContactsModel.h"
@@ -38,7 +59,7 @@
 // Started using settings ini
 //#define GV_S_VALUE_DB_VER   "2011-05-03 11:03:50"
 // SMS Text became rich text
-#define GV_S_VALUE_DB_VER   "2011-05-26 23:06:02"
+#define GV_S_VALUE_DB_VER   "2011-05-27 14:14:40"
 ////////////////////////////////////////////////////////////////////////////////
 // Started using versioning for the settings
 #define GV_SETTINGS_VER     "2011-05-13 16:33:50"
